@@ -23,19 +23,23 @@
 
 #include <stdlib.h>
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#define MODULE_NAME build
+#include <nALFS.h>
+
+#include "handlers.h"
 #include "backend.h"
 #include "logging.h"
 
 
-char handler_name[] = "build";
-char handler_description[] = "Build";
-char *handler_syntax_versions[] = { "2.0", NULL };
-// char *handler_attributes[] = { NULL };
-char *handler_parameters[] = { NULL };
-int handler_action = 0;
+#if HANDLER_SYNTAX_2_0
 
+static const char *build_parameters[] = { NULL };
 
-int handler_main(element_s *el)
+static int build_main(element_s *el)
 {
 	int i;
 
@@ -47,3 +51,29 @@ int handler_main(element_s *el)
 
 	return i;
 }
+
+#endif /* HANDLER_SYNTAX_2_0 */
+
+
+/*
+ * Handlers' information.
+ */
+
+handler_info_s HANDLER_SYMBOL(info)[] = {
+#if HANDLER_SYNTAX_2_0
+	{
+		.name = "build",
+		.description = "Build",
+		.syntax_version = "2.0",
+		.parameters = build_parameters,
+		.main = build_main,
+		.type = 0,
+		.alloc_data = NULL,
+		.is_action = 0,
+		.priority = 0
+	},
+#endif
+	{
+		NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0
+	}
+};
