@@ -23,19 +23,21 @@
 
 #include <stdlib.h>
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#define MODULE_NAME postbuild
+#include <nALFS.h>
+
+#include "handlers.h"
 #include "backend.h"
 #include "logging.h"
 
 
-char handler_name[] = "postbuild";
-char handler_description[] = "Post building";
-char *handler_syntax_versions[] = { "2.0", NULL };
-// char *handler_attributes[] = { NULL };
-char *handler_parameters[] = { NULL };
-int handler_action = 0;
+#if HANDLER_SYNTAX_2_0
 
-
-int handler_main(element_s *el)
+static int postbuild_main(element_s *el)
 {
 	int i;
 
@@ -47,3 +49,31 @@ int handler_main(element_s *el)
 
 	return i;
 }
+
+#endif /* HANDLER_SYNTAX_2_0 */
+
+
+/*
+ * Handlers' information.
+ */
+
+static const char *postbuild_parameters[] = { NULL };
+
+handler_info_s HANDLER_SYMBOL(info)[] = {
+#if HANDLER_SYNTAX_2_0
+	{
+		.name = "postbuild",
+		.description = "Post building",
+		.syntax_version = "2.0",
+		.parameters = postbuild_parameters,
+		.main = postbuild_main,
+		.type = 0,
+		.alloc_data = NULL,
+		.is_action = 0,
+		.priority = 0
+	},
+#endif
+	{
+		NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0
+	}
+};
